@@ -6,7 +6,7 @@ use warnings;
 
 use Fcntl ':flock';
 
-our $VERSION = '0.57'; # VERSION
+our $VERSION = '0.58'; # VERSION
 
 sub lock {
     my ($class, $path, $opts) = @_;
@@ -125,7 +125,7 @@ SHARYANTO::File::Flock - Yet another flock module
 
 =head1 VERSION
 
-This document describes version 0.57 of SHARYANTO::File::Flock (from Perl distribution SHARYANTO-File-Util), released on 2014-05-17.
+This document describes version 0.58 of SHARYANTO::File::Flock (from Perl distribution SHARYANTO-File-Util), released on 2014-11-23.
 
 =head1 SYNOPSIS
 
@@ -221,11 +221,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
